@@ -6,36 +6,36 @@ use Exporter 'import';
 use Scalar::Util 'refaddr';
 
 # Base type classes:
-use constant LISTTYPE   => 'Lingy::Lang::ListClass';
-use constant SCALARTYPE => 'Lingy::Lang::ScalarClass';
-use constant SEQUENTIAL => 'Lingy::Lang::Sequential';
+use constant LISTTYPE   => 'Lingy::ListClass';
+use constant SCALARTYPE => 'Lingy::ScalarClass';
+use constant SEQUENTIAL => 'Lingy::Sequential';
 
 # Type classes:
-use constant ATOM       => 'Lingy::Lang::Atom';
-use constant BOOLEAN    => 'Lingy::Lang::Boolean';
-use constant CHARACTER  => 'Lingy::Lang::Character';
-use constant CLASS      => 'Lingy::Lang::Class';
-use constant COMPILER   => 'Lingy::Lang::Compiler';
-use constant FUNCTION   => 'Lingy::Lang::Fn';
-use constant HASHMAP    => 'Lingy::Lang::HashMap';
-use constant KEYWORD    => 'Lingy::Lang::Keyword';
-use constant LIST       => 'Lingy::Lang::List';
-use constant MACRO      => 'Lingy::Lang::Macro';
-use constant NIL        => 'Lingy::Lang::Nil';
-use constant NUMBER     => 'Lingy::Lang::Number';
-use constant REGEX      => 'Lingy::Lang::Regex';
-use constant STRING     => 'Lingy::Lang::String';
-use constant SYMBOL     => 'Lingy::Lang::Symbol';
-use constant UTIL       => 'Lingy::Lang::Util';
-use constant VECTOR     => 'Lingy::Lang::Vector';
-use constant VAR        => 'Lingy::Lang::Var';
+use constant ATOM       => 'Lingy::Atom';
+use constant BOOLEAN    => 'Lingy::Boolean';
+use constant CHARACTER  => 'Lingy::Character';
+use constant CLASS      => 'Lingy::Class';
+use constant COMPILER   => 'Lingy::Compiler';
+use constant FUNCTION   => 'Lingy::Fn';
+use constant HASHMAP    => 'Lingy::HashMap';
+use constant KEYWORD    => 'Lingy::Keyword';
+use constant LIST       => 'Lingy::List';
+use constant MACRO      => 'Lingy::Macro';
+use constant NIL        => 'Lingy::Nil';
+use constant NUMBER     => 'Lingy::Number';
+use constant REGEX      => 'Lingy::Regex';
+use constant STRING     => 'Lingy::String';
+use constant SYMBOL     => 'Lingy::Symbol';
+use constant UTIL       => 'Lingy::Util';
+use constant VECTOR     => 'Lingy::Vector';
+use constant VAR        => 'Lingy::Var';
 
 # Functionality classes:
-use constant NAMESPACE  => 'Lingy::Lang::Namespace';
-use constant NUMBERS    => 'Lingy::Lang::Numbers';
-use constant RT         => 'Lingy::Lang::RT';
-use constant TERM       => 'Lingy::Lang::Term';
-use constant THREAD     => 'Lingy::Lang::Thread';
+use constant NAMESPACE  => 'Lingy::Namespace';
+use constant NUMBERS    => 'Lingy::Numbers';
+use constant RT         => 'Lingy::RT';
+use constant TERM       => 'Lingy::Term';
+use constant THREAD     => 'Lingy::Thread';
 
 BEGIN {
     our @EXPORT = qw<
@@ -79,6 +79,7 @@ BEGIN {
         string
         symbol
 
+        has
         err
         box_val
         unbox_val
@@ -97,7 +98,16 @@ BEGIN {
     >;
 }
 
-use Lingy::Printer;
+{
+    my ($n, $t, $f);
+    ($n, $t, $f) = (1, 1, 0);
+    my $nil = bless \$n, 'Lingy::Nil';
+    my $true = bless \$t, BOOLEAN;
+    my $false = bless \$f, BOOLEAN;
+    sub nil { $nil }
+    sub true { $true }
+    sub false { $false }
+}
 
 our $namespace_re = qr{(?:
     \w+
@@ -105,7 +115,7 @@ our $namespace_re = qr{(?:
 )}x;
 
 our $symbol_re = qr{(
-    \*?[-\w]+[\?\!\*\#]? |
+    \*?[-\w]+[\?\!\*\#\=]? |
     [-+*/<>] |
     ==? |
     <= |
@@ -119,13 +129,31 @@ sub list     { LIST->new(@_) }
 sub string   { STRING->new(@_) }
 sub symbol   { SYMBOL->new(@_) }
 
+sub has {
+    my ($caller) = caller;
+    my $name = shift;
+    my $method =
+        sub {
+            $#_
+                ? $_[0]{$name} = $_[1]
+                : $_[0]{$name};
+        };
+    no strict 'refs';
+    *{"${caller}::$name"} = $method;
+};
+
 sub err {
     my $msg = shift;
     $msg = sprintf $msg, @_;
-    die "Error:" .
-        ($msg =~ /\n./ ? "\n" : ' ') .
-        $msg .
-        "\n";
+
+    # XXX This is needed to keep the mal tests passing for now.
+    if ($ENV{LINGY_TEST}) {
+        $msg = "Error:" .
+            ($msg =~ /\n./ ? "\n" : ' ') .
+            $msg;
+    }
+
+    die "$msg\n";
 }
 
 sub box_val {
@@ -145,7 +173,7 @@ sub box_val {
 
 sub unbox_val {
     my ($obj) = @_;
-    ref($obj) =~ /^Lingy::Lang::(String|Number|Boolean|Fn)$/ ? $obj->unbox : $obj;
+    ref($obj) =~ /^Lingy::(String|Number|Boolean|Fn)$/ ? $obj->unbox : $obj;
 }
 
 sub assert_args {
@@ -173,7 +201,7 @@ sub comp_pair {
         my $i = 0;
         for my $e (@$x) {
             return 1 if $i > @$y;
-            my $r = comp_pair $x->[$i], $y->[$i];
+            my $r = comp_pair($x->[$i], $y->[$i]);
             return $r if $r;
             $i++;
         }
