@@ -3,8 +3,6 @@ package Lingy::Env;
 
 use Lingy::Common;
 
-sub space { shift->{space} }
-
 sub new {
     my ($class, %args) = @_;
     my $self = bless {
@@ -33,27 +31,23 @@ sub set {
     $space->{$symbol} = $value;
     return ref($space) eq 'HASH'
         ? $symbol
-        : symbol($space->NAME . "/$symbol");
-}
-
-sub ns_set {
-    my ($self, $symbol, $value) = @_;
-    my $space = RT->current_ns();
-    $space->{$symbol} = $value;
-    return ref($space) eq 'HASH'
-        ? $symbol
-        : symbol($space->NAME . "/$symbol");
+        : symbol($space->_name . "/$symbol");
 }
 
 sub get {
     my ($self, $symbol, $optional) = @_;
 
+    # XXX Temporary hack until Vars
+    if ("$symbol" eq '*ns*') {
+        return RT->current_ns;
+    }
+
     return $self->get_qualified($symbol, $optional)
         if $symbol =~ m{./.};
 
     while ($self) {
-        my $ns = $self->space;
-        if (defined(my $value = _referred($ns, $symbol))) {
+        my $space = $self->{space};
+        if (defined(my $value = $space->{$symbol})) {
             return $value;
         }
         $self = $self->{outer};
@@ -90,7 +84,7 @@ sub get_qualified {
     my $ns = RT->namespaces->{$space_name}
         or err "No such namespace: '$space_name'";
 
-    if (defined(my $value = _referred($ns, $symbol_name))) {
+    if (defined(my $value = $ns->{$symbol_name})) {
         return $value;
     }
 
@@ -99,25 +93,4 @@ sub get_qualified {
     err "Unable to resolve symbol: '$symbol' in this context";
 }
 
-sub _referred {
-    my ($ns, $symbol) = @_;
-    if (defined(my $value = $ns->{$symbol})) {
-        return $value;
-    }
-    if (ref($ns) ne 'HASH') {
-        if (my $refer_ns_map = RT->ns_refers->{$ns->NAME}) {
-            if (my $refer_ns_name = $refer_ns_map->{$symbol}) {
-                if (my $refer_ns =
-                    RT->namespaces->{$refer_ns_name}
-                ) {
-                    if (defined(my $value = $refer_ns->{$symbol})) {
-                        return $value;
-                    }
-                }
-            }
-        }
-    }
-    return;
-}
-
 1;
