@@ -17,21 +17,22 @@ my $escape = {
 
 sub pr_str {
     my ($self, $o, $raw) = (@_, 0);
+    $o //= '';
     my $type = ref $o;
 
     # Hack to allow map key strings to print like symbols:
     if (not $type and $o =~ /^($symbol_re|$namespace_re)$/) {
-        $type = 'Lingy::Lang::KeySymbol';
+        $type = 'Lingy::KeySymbol';
     }
 
-    $type or WWW $o, "Don't know how to print internal value '$o'";
+    $type or return WWW $o, "Don't know how to print internal value '$o'";
 
     $type eq ATOM ? "(atom ${\ $self->pr_str($o->[0], $raw)})" :
     $type eq STRING ? $raw ? $$o :
         qq{"${local $_ = $$o; s/([\n\t\"\\])/$escape->{$1}/ge; \$_}"} :
     $type eq REGEX ? $raw ? $$o :
-        qq{#"${local $_ = $$o; s/([\n\t\"\\])/$escape->{$1}/ge; \ substr($_, 4, length($_) - 5)}"} :
-    $type eq 'Lingy::Lang::KeySymbol' ? $o :
+        qq{#"${local $_ = $$o; \ substr($_, 4, length($_) - 5)}"} :
+    $type eq 'Lingy::KeySymbol' ? $o :
     $type eq SYMBOL ? $$o :
     $type eq KEYWORD ? $$o :
     $type eq NUMBER ? $$o :
@@ -64,7 +65,7 @@ sub pr_str {
     $type eq 'Lingy::Env' ? '#<Env>' :
     $type eq 'lingy-internal' ? "" :
     (blessed($o) and $o->isa(NAMESPACE)) ?
-        qq(#<Namespace ${\ $o->NAME}>) :
+        qq(#<Namespace ${\ $o->_name}>) :
     Dump($o) .
         "*** Unrecognized Lingy value printed above ***\n";
 }
