@@ -75,16 +75,15 @@ sub complete {
         return;
     }
 
-    my $space = RT->env->space;
+    my $space = RT->env->{space};
     my @names =
         grep {not /^ /} (
             keys(%$space),
             keys(%{RT->namespaces}),
-            keys(%{RT->ns_refers->{$space->NAME}}),
             map {
                 my $name = $_;
+                $name =~ s/^Lingy::/lingy.lang./;
                 $name =~ s/::/./g;
-                $name =~ s/^Lingy\.Lang\./lingy.lang./;
                 my $long = $name;
                 $name =~ s/.*\.//;
                 ($long, $name);
@@ -98,7 +97,7 @@ sub complete {
         $_
     } (
         @names,
-        Lingy::Eval->special_symbols,
+        Lingy::Evaluator->special_symbols,
     );
 }
 
